---
slug: /security-overview
---

# Security Overview

One of the key indicators of a database system is ensuring system security by preventing unauthorized use of the database through the database management system and protecting the files and data of the database. This topic describes the security features of seekdb.

As the ultimate carrier of data, seekdb is always focused on protecting data security. seekdb supports a comprehensive set of enterprise-level security features, including identity authentication, access control, and monitoring alerts, to effectively ensure user data security.

* Identity Authentication and Authorization

  seekdb supports identity identification and authentication, user management, and role management to enhance database security. For more information, see [Identity Authentication and Authorization](200.identification-and-authentication/100.identification.md).

* Access Control

 seekdb controls user access to data by defining various system, object, and role permissions. For more information, see [Access Control](300.access-control/100.access-control-overview.md).

* Data Encryption

  seekdb supports data encryption during data transmission. For more information, see [Data Transmission Encryption](400.data-transfer-encryption/100.data-transfer-encryption-overview.md).